@@ -9,16 +9,12 @@ import { connect } from 'react-redux'
 import msgs from '../../nls/platform.properties'
 import TruncateText from '../../components/common/TruncateText'
 import { updateModal } from '../../actions/common'
-import { POLICY_AUTOMATIONS } from '../../utils/client/queries'
-import { Query } from '@apollo/client/react/components'
 import { checkCreateRole, checkEditRole } from '../../utils/CheckUserPermission'
 import {
     AcmLaunchLink
-} from '@stolostron/ui-components'
-import {
-    Button,
-    Spinner,
-} from '@patternfly/react-core'
+} from '@open-cluster-management/ui-components'
+import { Button } from '@patternfly/react-core'
+import _ from 'lodash'
 
 import '../../scss/resource-filterbar.scss'
 import { createDisableTooltip } from './DisableTooltip'
@@ -29,34 +25,18 @@ class AutomationButton extends React.Component {
   }
 
   render() {
-    const { item, locale, userAccess } = this.props
+    const { item, locale, userAccess, refetch } = this.props
     const automationAccess = this.checkPermissions(userAccess, item.metadata.namespace)
-    return (
-        <Query query={POLICY_AUTOMATIONS} variables={{ namespace: item.metadata.namespace }}>
-        {( result ) => {
-          const { data={policyAutomations: []} } = result
-          const { loading } = result
-          let found = false
-          let automationName = ''
-          data.policyAutomations.forEach((automation) => {
-            if (automation.spec && automation.spec.policyRef === item.metadata.name) {
-              found = true
-              automationName = automation.metadata.name
-            }
-          })
-          if (loading) {
-            return <Spinner size='md' />
-          }
-          if (found) {
-            return this.automationLaunch(item, automationName, automationAccess, locale)
-          }
-          return this.automationConfigure(item, automationAccess, locale)
-        }}
-        </Query>
-      )
+    const policyAutomation = _.get(item, 'policyAutomation')
+    if (policyAutomation) {
+      const automationName = _.get(policyAutomation, 'metadata.name')
+      return this.automationLaunch(item, automationName, automationAccess, locale, refetch)
+    } else {
+      return this.automationConfigure(item, automationAccess, locale, refetch)
+    }
   }
 
-  automationLaunch(item, automationName, automationAccess, locale) {
+  automationLaunch(item, automationName, automationAccess, locale, refetch) {
     const label = 'automationButton'
     const onlyEdit = !automationAccess.CREATE
     const isDisabled = !automationAccess.CREATE && !automationAccess.EDIT
@@ -72,7 +52,7 @@ class AutomationButton extends React.Component {
             noTooltip={isDisabled ? true : false}
             />,
             onClick: isDisabled ? undefined : () => {
-              this.props.onClickAutomation(item, onlyEdit)
+              this.props.onClickAutomation(item, refetch, onlyEdit)
             },
             label: true,
             noIcon: true,
@@ -82,7 +62,7 @@ class AutomationButton extends React.Component {
     return createDisableTooltip(isDisabled, label, locale, configureButton)
   }
 
-  automationConfigure(item, automationAccess, locale) {
+  automationConfigure(item, automationAccess, locale, refetch) {
     const label = 'automationButton'
     const isDisabled = !automationAccess.CREATE
     const configureButton = (
@@ -92,7 +72,7 @@ class AutomationButton extends React.Component {
         className={label}
         isDisabled={isDisabled}
         onClick= {() => {
-          this.props.onClickAutomation(item)
+          this.props.onClickAutomation(item, refetch)
         }}
       >
         {msgs.get('table.actions.automation.configure', locale)}
@@ -107,12 +87,14 @@ class AutomationButton extends React.Component {
       CREATE: false,
       EDIT: false
     }
-    const accessObj = access.filter(role => role.namespace === ns)
-    if (accessObj.length > 0 && accessObj[0].rules) {
-      // Check for permissions on Policy and PolicyAutomation resources
-      const resources = [ 'policy.open-cluster-management.io/policyautomations' ]
-      automationAccess.CREATE = checkCreateRole(accessObj[0].rules, resources) === 1
-      automationAccess.EDIT = checkEditRole(accessObj[0].rules, resources) === 1
+    if(Array.isArray(access) && access.length > 0) {
+      const accessObj = access.filter(role => role.namespace === ns)
+      if (accessObj.length > 0 && accessObj[0].rules) {
+        // Check for permissions on Policy and PolicyAutomation resources
+        const resources = [ 'policy.open-cluster-management.io/policyautomations' ]
+        automationAccess.CREATE = checkCreateRole(accessObj[0].rules, resources) === 1
+        automationAccess.EDIT = checkEditRole(accessObj[0].rules, resources) === 1
+      }
     }
     return automationAccess
   }
@@ -122,6 +104,7 @@ AutomationButton.propTypes = {
   item: PropTypes.object,
   locale: PropTypes.string,
   onClickAutomation: PropTypes.func,
+  refetch: PropTypes.func,
   userAccess: PropTypes.array,
 }
 
@@ -130,7 +113,7 @@ const mapDispatchToProps = (dispatch) => {
     name: 'HCMCompliance',
   }
   return {
-    onClickAutomation: (data, onlyEdit) => {
+    onClickAutomation: (data, refetch, onlyEdit) => {
       dispatch(updateModal(
         { open: true, type: 'resource-automation', resourceTypeAuto,
           label: {
@@ -139,6 +122,7 @@ const mapDispatchToProps = (dispatch) => {
             heading: `modal.automation-${resourceTypeAuto.name.toLowerCase()}.heading`
           },
           data: { kind: resourceTypeAuto.name, ...data },
+          refetch,
           onlyEdit
         }))
     }
