@@ -9,7 +9,7 @@ import classNames from 'classnames'
 import PropTypes from 'prop-types'
 import { Alert, AlertActionCloseButton, Checkbox, ButtonVariant, Spinner, Select,
   SelectVariant, SelectOption, TextInput, ValidatedOptions, Radio } from '@patternfly/react-core'
-import { AcmModal, AcmButton, AcmAlert } from '@stolostron/ui-components'
+import { AcmModal, AcmButton, AcmAlert } from '@open-cluster-management/ui-components'
 import { initializeControlData, cacheUserData, updateControls, parseYAML,
   dumpYAMLFromPolicyDiscovered, dumpYAMLFromTemplateObject } from './utils/update-controls'
 import { GrayOutlinedQuestionCircleIcon } from '../Icons'
@@ -21,6 +21,7 @@ import msgs from '../../../nls/platform.properties'
 import '../../../graphics/diagramIcons.svg'
 import { LocaleContext } from '../../../components/common/LocaleContext'
 import _ from 'lodash'
+import { generalDocLink } from '../CreateDocLink'
 
 const tempCookie = 'template-editor-open-cookie'
 // const diagramIconsInfoStr = '#diagramIcons_info'
@@ -51,6 +52,7 @@ export default class TemplateEditor extends React.Component {
       isFailed: PropTypes.bool,
       error: PropTypes.object
     }),
+    hasExternalAlert: PropTypes.bool,
     isEdit: PropTypes.bool,
     locale: PropTypes.string,
     onCreate: PropTypes.func.isRequired,
@@ -203,10 +205,12 @@ export default class TemplateEditor extends React.Component {
   }
 
   renderSplitEditor() {
+    const { hasExternalAlert } = this.props
     const { showEditor } = this.state
     const editorClasses = classNames({
       'creation-view-split-container': true,
-      showEditor
+      showEditor,
+      hasExternalAlert
     })
     return (
       <div className={editorClasses}>
@@ -233,10 +237,14 @@ export default class TemplateEditor extends React.Component {
   }
 
   renderControls() {
-    const { locale } = this.props
+    const { hasExternalAlert, locale } = this.props
     const {controlData} = this.state
+    const editorClasses = classNames({
+      'creation-view-controls-container': true,
+      hasExternalAlert
+    })
     return (
-      <div className='creation-view-controls-container' >
+      <div className={editorClasses} >
         {this.renderNotifications()}
         <div className='creation-view-controls-note'>{msgs.get('creation.view.required.mark', locale)}</div>
         <div className='creation-view-controls' >
@@ -345,6 +353,7 @@ export default class TemplateEditor extends React.Component {
   }
 
   renderCheckbox(control) {
+    const {locale} = this.props
     const {id, name, description, checked, available, active} = control
     if (id === 'remediation') {
       const radioButtons=[]
@@ -353,7 +362,13 @@ export default class TemplateEditor extends React.Component {
             isChecked={item===active}
             name={`${id}-${item}`}
             onChange={this.handleChange.bind(this, id)}
-            label={msgs.get(`creation.view.policy.${item}`)}
+            label={<React.Fragment>
+              {msgs.get(`creation.view.policy.${item}`)}
+              {item === 'enforce' && generalDocLink(
+                locale,
+                ` ${msgs.get('creation.view.policy.doc', locale)}`,
+                'html/governance/governance#kubernetes-configuration-policy-controller')}
+            </React.Fragment>}
             aria-label={`${id}-${item}`}
             id={`${id}-${item}`}
             key={`${id}-${item}`}
