@@ -4,7 +4,7 @@
 'use strict'
 
 import React from 'react'
-import { AcmButton } from '@stolostron/ui-components'
+import { AcmButton } from '@open-cluster-management/ui-components'
 import { ButtonVariant } from '@patternfly/react-core'
 import { createDisableTooltip } from '../../common/DisableTooltip'
 import msgs from '../../../nls/platform.properties'
@@ -25,27 +25,27 @@ export const buildModalButtonList = ({
             {msgs.get('modal.button.save', locale)}
         </AcmButton>
       )
-      actions.push(
+    }
+    actions.push(
+      <AcmButton
+        key="cancel"
+        variant={ButtonVariant.secondary}
+        onClick={handleCloseClick}
+      >
+          {msgs.get('modal.button.cancel', locale)}
+      </AcmButton>
+    )
+    if (!activeItem && policyAutoName) {
+      const delButton = (
         <AcmButton
-          key="cancel"
-          variant={ButtonVariant.secondary}
-          onClick={handleCloseClick}
-        >
-            {msgs.get('modal.button.cancel', locale)}
-        </AcmButton>
-      )
-      if (policyAutoName) {
-        const delButton = (
-          <AcmButton
-            key="delete"
-            variant={ButtonVariant.danger}
-            isDisabled={onlyEdit}
-            onClick={onlyEdit? undefined : handleOpenDelModal}
-            >
-              {msgs.get('modal.button.delete', locale)}
-            </AcmButton>)
-        actions.push(createDisableTooltip(onlyEdit, 'delete', locale, delButton))
-      }
+          key="delete"
+          variant={ButtonVariant.danger}
+          isDisabled={onlyEdit}
+          onClick={onlyEdit? undefined : handleOpenDelModal}
+          >
+            {msgs.get('modal.button.delete', locale)}
+          </AcmButton>)
+      actions.push(createDisableTooltip(onlyEdit, 'delete', locale, delButton))
     }
     return actions
   }
