@@ -8,7 +8,7 @@ import { connect } from 'react-redux'
 import PropTypes from 'prop-types'
 import {
   AcmModal, AcmExpandableCard,
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 import {
   Text, Spinner, Select, Title,
   SelectOption, SelectVariant, Radio, Alert,
@@ -18,7 +18,7 @@ import MonacoEditor from 'react-monaco-editor'
 import msgs from '../../../nls/platform.properties'
 import {
   modifyPolicyAutomation, clearRequestStatus,
-  updateModal, copyAnsibleSecret, getPolicyAutomation
+  updateModal, copyAnsibleSecret
 } from '../../../actions/common'
 import { getPolicyCompliantStatus } from '../../../tableDefinitions/utils'
 import { Query } from '@apollo/client/react/components'
@@ -74,6 +74,9 @@ export class AnsibleAutomationModal extends React.Component {
       notificationOpen: true,
       openDelModal:false,
     }
+  }
+
+  componentDidMount() {
     this.initialize()
   }
 
@@ -129,46 +132,39 @@ export class AnsibleAutomationModal extends React.Component {
   }
 
   initialize = async () => {
-    const {  data:policyData, handleGetPolicyAutomation } = this.props
-    const policyName = _.get(policyData, metaNameStr)
-    const policyNS = _.get(policyData, metaNSStr)
-    // step to check and loading exisiting policyAutomations
-    const {data:initialData} = await handleGetPolicyAutomation(policyNS)
-    const policyAutomations = initialData.policyAutomations
-    if ( Array.isArray(policyAutomations) && policyAutomations.length > 0) {
-      // targetPolicyAutomation must match policy name and ns
-      const targetPolicyAutomation = _.find(policyAutomations, ['spec.policyRef', policyName])
-      if (targetPolicyAutomation) {
-        const policyAutoName = _.get(targetPolicyAutomation, metaNameStr)
-        const policyAutoNS = _.get(targetPolicyAutomation, metaNSStr)
-        let annotations = _.get(targetPolicyAutomation, 'metadata.annotations')
-        const resourceVersion = _.get(targetPolicyAutomation, 'metadata.resourceVersion')
-        const credentialName = _.get(targetPolicyAutomation, 'spec.automationDef.secret')
-        const jobTemplateName = _.get(targetPolicyAutomation, 'spec.automationDef.name')
-        const extraVarsJSON = _.get(targetPolicyAutomation, extraVarsStr)
-        let extraVars = null
-        if (typeof extraVarsJSON === 'object' && Object.keys(extraVarsJSON).length > 0) {
-          extraVars = this.jsonToYAML(extraVarsJSON)
-        }
-        let ansScheduleMode = _.get(targetPolicyAutomation, 'spec.mode')
-        if (annotations && annotations['policy.open-cluster-management.io/rerun'] === 'true') {
-          ansScheduleMode = 'manual'
-        } else {
-          annotations = {'policy.open-cluster-management.io/rerun':'false'}
-        }
-        const initialJSON = this.buildPolicyAutomationJSON({
-          policyAutoName, policyAutoNS, policyName, annotations, resourceVersion,
-          extraVars, credentialName, jobTemplateName, ansScheduleMode
-        })
-        this.setState({
-          policyAutoName,
-          credentialName,
-          jobTemplateName,
-          extraVars,
-          ansScheduleMode,
-          initialJSON
-        })
+    const { data } = this.props
+    const policyName = _.get(data, metaNameStr)
+    const policyAutomation = _.get(data, 'policyAutomation')
+    if (policyAutomation) {
+      const policyAutoName = _.get(policyAutomation, metaNameStr)
+      const policyAutoNS = _.get(policyAutomation, metaNSStr)
+      let annotations = _.get(policyAutomation, 'metadata.annotations')
+      const resourceVersion = _.get(policyAutomation, 'metadata.resourceVersion')
+      const credentialName = _.get(policyAutomation, 'spec.automationDef.secret')
+      const jobTemplateName = _.get(policyAutomation, 'spec.automationDef.name')
+      const extraVarsJSON = _.get(policyAutomation, extraVarsStr)
+      let extraVars = null
+      if (typeof extraVarsJSON === 'object' && Object.keys(extraVarsJSON).length > 0) {
+        extraVars = this.jsonToYAML(extraVarsJSON)
       }
+      let ansScheduleMode = _.get(policyAutomation, 'spec.mode')
+      if (annotations && annotations['policy.open-cluster-management.io/rerun'] === 'true') {
+        ansScheduleMode = 'manual'
+      } else {
+        annotations = {'policy.open-cluster-management.io/rerun':'false'}
+      }
+      const initialJSON = this.buildPolicyAutomationJSON({
+        policyAutoName, policyAutoNS, policyName, annotations, resourceVersion,
+        extraVars, credentialName, jobTemplateName, ansScheduleMode
+      })
+      this.setState({
+        policyAutoName,
+        credentialName,
+        jobTemplateName,
+        extraVars,
+        ansScheduleMode,
+        initialJSON
+      })
     }
     this.setState({
       initializeFinished: true,
@@ -269,7 +265,7 @@ export class AnsibleAutomationModal extends React.Component {
 
   handleSubmitClick = async (inputAction) => {
     const { yamlMsg, initialJSON } = this.state
-    const { locale } = this.props
+    const { locale, refetch } = this.props
     const generateJSONResult = Promise.resolve(this.generateJSON())
     const {latestJSON, action} = await generateJSONResult
     let submitAction = action
@@ -290,6 +286,9 @@ export class AnsibleAutomationModal extends React.Component {
         this.initialize()
         this.setQueryAlert(msgs.get(`ansible.${ansScheduleMode}.success`, locale), 'success')
         this.handleCloseSlideOut()
+        // call refetch to refresh policy automation icon
+        // on all policy page / policy detail page after updating
+        refetch()
       }
     }
   }
@@ -608,7 +607,7 @@ export class AnsibleAutomationModal extends React.Component {
           const { data={}, error={} } = result
           const queryError = this.getQueryError(error)
           const ansJobTemplates = data ? data.ansibleJobTemplates : data
-          const ansJobTemplateFlag = !queryError && Array.isArray(ansJobTemplates) && ansJobTemplates.length > 0
+          const ansJobTemplateFlag = !queryError && !loading && Array.isArray(ansJobTemplates) && ansJobTemplates.length > 0
           const {jobTemplateName, jobTemplateIsOpen, notificationOpen} = this.state
           return (
             <React.Fragment>
@@ -648,7 +647,7 @@ export class AnsibleAutomationModal extends React.Component {
                   {jobTemplateName && this.renderAnsibleJobTemplateEditor()}
                   {jobTemplateName && this.renderAnsibleScheduleMode()}
                 </React.Fragment>}
-                {!ansJobTemplateFlag && notificationOpen &&
+                {!ansJobTemplateFlag && !loading && notificationOpen &&
                 <div className='infoArea'>
                   <Alert
                     variant={'info'}
@@ -753,11 +752,11 @@ AnsibleAutomationModal.propTypes = {
   data: PropTypes.object,
   handleClose: PropTypes.func,
   handleCopyAnsibleSecret: PropTypes.func,
-  handleGetPolicyAutomation: PropTypes.func,
   handleModifyPolicyAutomation: PropTypes.func,
   locale: PropTypes.string,
   onlyEdit: PropTypes.bool,
   open: PropTypes.bool,
+  refetch: PropTypes.func,
   type: PropTypes.string,
 }
 
@@ -774,9 +773,7 @@ const mapDispatchToProps = (dispatch) => {
     handleModifyPolicyAutomation: (poliyAutomationJSON, action) =>
       dispatch(modifyPolicyAutomation(poliyAutomationJSON, action)),
     handleCopyAnsibleSecret: (name, namespace, targetNamespace) =>
-      dispatch(copyAnsibleSecret(name, namespace, targetNamespace)),
-    handleGetPolicyAutomation: (namespace) =>
-      dispatch(getPolicyAutomation(namespace)),
+      dispatch(copyAnsibleSecret(name, namespace, targetNamespace))
   }
 }
 
