@@ -14,11 +14,11 @@ import {
 import {
   AcmTable,
   AcmTablePaginationContextProvider
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 import { LocaleContext } from '../common/LocaleContext'
 import grcPoliciesViewDef from '../../tableDefinitions/grcPoliciesViewDef'
 import grcClustersViewDef from '../../tableDefinitions/grcClustersViewDef'
-import { transform } from '../../tableDefinitions/utils'
+import { transform, getTableFilters } from '../../tableDefinitions/utils'
 import msgs from '../../nls/platform.properties'
 import { formatPoliciesToClustersTableData } from '../../utils/FormatTableData'
 import { RESOURCE_TYPES, GRC_SEARCH_STATE_COOKIE } from '../../utils/constants'
@@ -27,6 +27,7 @@ import { resourceActions } from '../common/ResourceTableRowMenuItemActions'
 import formatUserAccess from '../../utils/FormatUserAccess'
 import filterUserAction from '../../utils/FilterUserAction'
 import { REQUEST_STATUS } from '../../actions/index'
+import { updateModal } from '../../actions/common'
 import {
   getSessionState, replaceSessionPair
 } from '../../utils/AccessStorage'
@@ -45,7 +46,7 @@ class GrcToggleModule extends React.Component {
   static contextType = LocaleContext
 
   render() {
-    const { grcItems, grcTabToggleIndex, handleToggleClick, status } = this.props
+    const { grcItems, grcTabToggleIndex, handleToggleClick, status, onClickTableAction } = this.props
     const { locale } = this.context
     const tableType = grcTabToggleIndex === 0 ? 'policies' : 'clusters'
     const tableData = [
@@ -78,6 +79,50 @@ class GrcToggleModule extends React.Component {
           </ToggleGroupItem>
         </ToggleGroup>
     )
+    const policyActionDefs = [
+      {
+        id: 'status-group',
+        title: 'Status',
+        actions: [
+          {
+            id: 'enable',
+            title: 'Enable',
+            click: (it) => onClickTableAction(it, 'enable'),
+            variant: 'bulk-action',
+          },
+          {
+            id: 'disable',
+            title: 'Disable',
+            click: (it) => onClickTableAction(it, 'disable'),
+            variant: 'bulk-action',
+          },
+        ],
+        variant: 'action-group',
+      },
+      {
+        id: 'separator-1',
+        variant: 'action-seperator',
+      },
+      {
+        id: 'remediation-group',
+        title: 'Remediation',
+        actions: [
+          {
+            id: 'inform',
+            title: 'Inform',
+            click: (it) => onClickTableAction(it, 'inform'),
+            variant: 'bulk-action',
+          },
+          {
+            id: 'enforce',
+            title: 'Enforce',
+            click: (it) => onClickTableAction(it, 'enforce'),
+            variant: 'bulk-action',
+          },
+        ],
+        variant: 'action-group',
+      },
+    ]
     return (
       <div className='grc-toggle'>
         <div className={`grc-view-by-${tableType}-table`}>
@@ -88,14 +133,16 @@ class GrcToggleModule extends React.Component {
               rowActionResolver={this.tableActionResolver}
               addSubRows={tableData[grcTabToggleIndex].addSubRows}
               keyFn={tableData[grcTabToggleIndex].keyFn}
-              setSearch={searchValue}
+              search={searchValue}
+              setSearch={this.handleSearch}
               sort={sortValues[grcTabToggleIndex]}
               setSort={this.setSort(grcTabToggleIndex)}
-              gridBreakPoint=''
               extraToolbarControls={extraToolbarControls}
               searchPlaceholder={msgs.get('tabs.grc.toggle.allPolicies.placeHolderText', locale)}
               fuseThreshold={0}
               plural={grcTabToggleIndex === 0 ? 'policies' : 'violations'}
+              filters={grcTabToggleIndex === 0 ? getTableFilters(tableData[0].rows) : []}
+              tableActions={grcTabToggleIndex === 0 ? policyActionDefs : []}
             />
           </AcmTablePaginationContextProvider>
         </div>
@@ -152,7 +199,7 @@ class GrcToggleModule extends React.Component {
       } else {
         filteredActions[filteredActions.indexOf('table.actions.enable')] = 'table.actions.disable'
       }
-      if (_.get(rowData, 'remediation', 'inform') === 'enforce') {
+      if (_.get(rowData, 'remediation.rawData', 'inform') === 'enforce') {
         filteredActions[filteredActions.indexOf('table.actions.enforce')] = 'table.actions.inform'
       } else {
         filteredActions[filteredActions.indexOf('table.actions.inform')] = 'table.actions.enforce'
@@ -199,6 +246,7 @@ GrcToggleModule.propTypes = {
   grcTabToggleIndex: PropTypes.number,
   handleToggleClick: PropTypes.func,
   history: PropTypes.object.isRequired,
+  onClickTableAction: PropTypes.func,
   status: PropTypes.string,
   userAccess: PropTypes.array,
 }
@@ -215,7 +263,21 @@ const mapStateToProps = (state) => {
 const mapDispatchToProps = (dispatch) => {
   return {
     getResourceAction: (action, resource, resourceType, history) =>
-      resourceActions(action, dispatch, resourceType, resource, history)
+      resourceActions(action, dispatch, resourceType, resource, history),
+    onClickTableAction: (data, actionType) => {
+      dispatch(updateModal({
+        open: true,
+        actionType,
+        type: `bulk-policy-action-${actionType}`,
+        resourceType: 'Policy',
+        label: {
+          primaryBtn: `modal.actions.bulk.${actionType}.primaryBtn`,
+          label: 'label',
+          heading: `modal.actions.bulk.${actionType}.heading`
+        },
+        data,
+      }))
+    }
   }
 }
 
