@@ -4,7 +4,7 @@
 
 'use strict'
 import React from 'react'
-import { AcmButton, AcmSecondaryNavItem } from '@stolostron/ui-components'
+import { AcmButton, AcmSecondaryNavItem } from '@open-cluster-management/ui-components'
 
 import { ALL_POLICIES, SINGLE_POLICY, POLICY_STATUS, POLICY_STATUS_HISTORY, POLICY_TEMPLATE_DETAILS } from '../../utils/client/queries'
 import config from '../../../server/lib/shared/config'
@@ -27,8 +27,10 @@ export const getPageDefinition = (props) => {
       return policiesPage(props)
     case 'SINGLE_POLICY':
       return policyDetailsPage(props)
-    case 'POLICY_STATUS':
-      return policyStatusPage(props)
+    case 'POLICY_CLUSTERS':
+      return policyClustersPage(props)
+    case 'POLICY_TEMPLATES':
+      return policyTemplatesPage(props)
     case 'POLICY_TEMPLATE_DETAILS':
       return policyTemplateDetailsPage(props)
     case 'POLICY_STATUS_HISTORY':
@@ -47,10 +49,11 @@ const createBtn = ({ userAccess, history, locale }) => {
   )
 }
 
-const editBtn = ({ userAccess, history, locale, name, namespace }) => {
+const editBtn = ({ userAccess, history, locale, name, namespace, resourceNotFound }) => {
+  const noPermission = checkEditPermission(userAccess) === 0
   return (
-    <AcmButton key='edit-policy' id='edit-policy' isDisabled={checkEditPermission(userAccess)===0}
-      tooltip={msgs.get('error.permission.disabled', locale)}
+    <AcmButton key='edit-policy' id='edit-policy' isDisabled={noPermission || resourceNotFound}
+      tooltip={noPermission ? msgs.get('error.permission.disabled', locale) : msgs.get('error.not.found', locale)}
       onClick={() => history.push(`${config.contextPath}/all/${namespace}/${name}/edit`)}>
       {msgs.get('routes.edit.policy', locale)}
     </AcmButton>
@@ -67,12 +70,22 @@ const detailsNav = ({ history, locale, name, namespace }) => {
   )
 }
 
-const statusNav = ({ history, locale, name, namespace }) => {
-  const url = `${config.contextPath}/all/${namespace}/${name}/status`
+const clustersNav = ({ history, locale, name, namespace }) => {
+  const url = `${config.contextPath}/all/${namespace}/${name}/clusters`
   return (
-    <AcmSecondaryNavItem key='status' isActive={history.location.pathname===url}
+    <AcmSecondaryNavItem key='clusters' isActive={history.location.pathname===url}
       onClick={() => history.push(url)}>
-      {msgs.get('tabs.status', locale)}
+      {msgs.get('tabs.clusters', locale)}
+    </AcmSecondaryNavItem>
+  )
+}
+
+const templatesNav = ({ history, locale, name, namespace }) => {
+  const url = `${config.contextPath}/all/${namespace}/${name}/templates`
+  return (
+    <AcmSecondaryNavItem key='templates' isActive={history.location.pathname===url}
+      onClick={() => history.push(url)}>
+      {msgs.get('tabs.templates', locale)}
     </AcmSecondaryNavItem>
   )
 }
@@ -101,16 +114,17 @@ const policyDetailsPage = ({ name, namespace, locale }) => {
     ],
     navigation: [
       detailsNav,
-      statusNav
+      clustersNav,
+      templatesNav
     ],
     buttons: [ editBtn ],
     children: (props) => <PolicyDetailsOverview {...props} />
   }
 }
 
-const policyStatusPage = ({ name, namespace, locale }) => {
+const policyClustersPage = ({ name, namespace, locale }) => {
   return {
-    id: 'policy-status',
+    id: 'policy-clusters',
     title: name,
     query: POLICY_STATUS,
     query_variables: { policyName: name, hubNamespace: namespace },
@@ -121,10 +135,32 @@ const policyStatusPage = ({ name, namespace, locale }) => {
     ],
     navigation: [
       detailsNav,
-      statusNav
+      clustersNav,
+      templatesNav
     ],
     buttons: [ editBtn ],
-    children: (props) => <PolicyStatusView {...props} />
+    children: (props) => <PolicyStatusView {...props} grouping='clusters' />
+  }
+}
+
+const policyTemplatesPage = ({ name, namespace, locale }) => {
+  return {
+    id: 'policy-templates',
+    title: name,
+    query: POLICY_STATUS,
+    query_variables: { policyName: name, hubNamespace: namespace },
+    refreshControls: true,
+    breadcrumb: [
+      { text: msgs.get(policiesMsg, locale), to: config.contextPath },
+      { text: name, to: name }
+    ],
+    navigation: [
+      detailsNav,
+      clustersNav,
+      templatesNav
+    ],
+    buttons: [ editBtn ],
+    children: (props) => <PolicyStatusView {...props} grouping='templates' />
   }
 }
 
@@ -139,7 +175,6 @@ const policyTemplateDetailsPage = ({ name, namespace, cluster, apiGroup, version
     breadcrumb: [
       { text: msgs.get(policiesMsg, locale), to: config.contextPath },
       { text: name, to: `${config.contextPath}/all/${namespace}/${name}`},
-      { text: msgs.get('table.header.status', locale), to: `${config.contextPath}/all/${namespace}/${name}/status` },
       { text: template, to: template }
     ],
     children: (props) => <PolicyTemplateDetailsView {...props} selfLink={selfLink} />
@@ -156,7 +191,6 @@ const policyStatusHistoryPage = ({ name, namespace, cluster, template, locale })
     breadcrumb: [
       { text: msgs.get(policiesMsg, locale), to: config.contextPath },
       { text: name, to: `${config.contextPath}/all/${namespace}/${name}`},
-      { text: msgs.get('table.header.status', locale), to: `${config.contextPath}/all/${namespace}/${name}/status`},
       { text: msgs.get(historyMsg, locale), to: msgs.get(historyMsg, locale) }
     ],
     children: (props) => <PolicyStatusHistoryView {...props} cluster={cluster} template={template} />
