@@ -12,25 +12,28 @@ describeT('RHACM4K-247 - GRC UI: [P1][Sev1][console] Create policy with invalid
   it('Create policy should fail with invalid policy name in yaml', () => {
     const confFilePolicy = 'InvalidYamlTests/InvalidPolicyName.yaml'
     const rawPolicyYAML = getConfigObject(confFilePolicy, 'raw', getDefaultSubstitutionRules())
-    cy.visit('/multicloud/policies/create')
+    cy.waitUntil(() => cy.visit('/multicloud/policies/create')
       .createPolicyFromYAML(rawPolicyYAML, false)
-      .get('#create').click()
-      .checkNotificationMessage('Danger Alert', 'Create error:', invalidYamlErrorMessages['invalidName']['msg'])
+      .get('#create').scrollIntoView().should('be.visible')
+      .click()
+    ) .checkNotificationMessage('Danger Alert', 'Create error:', invalidYamlErrorMessages['invalidName']['msg'])
   })
   it('Create policy should fail with missing namespace in yaml', () => {
     const confFilePolicy = 'InvalidYamlTests/MissingNamespace.yaml'
     const rawPolicyYAML = getConfigObject(confFilePolicy, 'raw', getDefaultSubstitutionRules())
-    cy.visit('/multicloud/policies/create')
+    cy.waitUntil(() => cy.visit('/multicloud/policies/create')
       .createPolicyFromYAML(rawPolicyYAML, false)
-      .get('#create').click()
-      .checkNotificationMessage('Danger Alert', 'Create error:', invalidYamlErrorMessages['missingNamespace']['msg'])
+      .get('#create').scrollIntoView().should('be.visible')
+      .click()
+    ) .checkNotificationMessage('Danger Alert', 'Create error:', invalidYamlErrorMessages['missingNamespace']['msg'])
   })
   it('Create policy should fail with invalid indentation in yaml', () => {
     const confFilePolicy = 'InvalidYamlTests/InvalidIndentation.yaml'
     const rawPolicyYAML = getConfigObject(confFilePolicy, 'raw', getDefaultSubstitutionRules())
-    cy.visit('/multicloud/policies/create')
+    cy.waitUntil(() => cy.visit('/multicloud/policies/create')
       .createPolicyFromYAML(rawPolicyYAML, false)
-      .get('#create').click()
-      .checkNotificationMessage('Danger Alert', 'Create error:', invalidYamlErrorMessages['badIndentation']['msg'])
+      .get('#create').scrollIntoView().should('be.visible')
+      .click()
+    ) .checkNotificationMessage('Danger Alert', 'Create error:', invalidYamlErrorMessages['badIndentation']['msg'])
   })
 })
