@@ -82,7 +82,7 @@ describeT('@rbac RHACM4K-2584 - GRC UI: [P1][Sev1][console] Role Based Access Co
   /***********
    * Cleanup *
    ***********/
-  it('Login again as kubeadmin', () => {
+  it('Login again as cluster admin', () => {
     cy.login()
   })
 
