@@ -24,8 +24,8 @@ describeT('RHACM4K-2349 - GRC UI: [P1][Sev1][console] Create policy page: Check
   it('Check that invalid policy name pattern issues an error', () => {
     cy.FromGRCToCreatePolicyPage()
     for (const [name, namespace, message] of namePatterns) {
-      cy.createPolicyFromSelection(name, false, {'namespace': namespace})
-        .get('#create').click()  // click create
+      cy.waitUntil(() => cy.createPolicyFromSelection(name, false, {'namespace': namespace}).get('#create').scrollIntoView().should('be.visible'))
+        .click()
         .checkNotificationMessage('Danger Alert', 'Create error:', message)
     }
   })
