@@ -43,7 +43,8 @@ describeT('@extended RHACM4K-1648 - GRC UI: [P2][Sev2][console] CertPolicy with
   })
 
   it('Create a customized policy', () => {
-    cy.get('#create').click()
+    cy.waitUntil(() => cy.get('#create').scrollIntoView().should('be.visible'))
+    cy.get('#create').scrollIntoView().should('be.visible').click()
     // after creation, always return to grc main page
     cy.CheckGrcMainPage()
   })
@@ -57,7 +58,7 @@ describeT('@extended RHACM4K-1648 - GRC UI: [P2][Sev2][console] CertPolicy with
   })
 
   it(`Verify policy ${policyName} violations at the Status - Clusters page`, () => {
-    cy.visit(`/multicloud/policies/all/${confPolicy['namespace']}/${policyName}/status`).waitForPageContentLoad()
+    cy.visit(`/multicloud/policies/all/${confPolicy['namespace']}/${policyName}/clusters`).waitForPageContentLoad()
     // verify all violations per cluster
       .verifyViolationsInPolicyStatusClusters(policyName, confPolicy, clusterViolations, confViolationPatterns)
   })
