@@ -11,7 +11,7 @@
 
 'use strict'
 
-import { createDocLink } from '../../../../src-web/components/common/CreateDocLink'
+import { createDocLink, generalDocLink } from '../../../../src-web/components/common/CreateDocLink'
 
 describe('createDocLink view', () => {
   const handleCreatePolicy = jest.fn()
@@ -25,3 +25,11 @@ describe('createDocLink view', () => {
     expect(component).toMatchSnapshot()
   })
 })
+
+describe('generalDocLink view', () => {
+  it('renders show general GRC doc link as expected', () => {
+    const component = generalDocLink('en-US', 'product documentation',
+    'html/governance/governance#kubernetes-configuration-policy-controller')
+    expect(component).toMatchSnapshot()
+  })
+})
